/****************************************************************************
** Meta object code from reading C++ file 'idlejob.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kimap-17.12.3/src/idlejob.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'idlejob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KIMAP__IdleJob_t {
    QByteArrayData data[13];
    char stringdata0[141];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KIMAP__IdleJob_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KIMAP__IdleJob_t qt_meta_stringdata_KIMAP__IdleJob = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KIMAP::IdleJob"
QT_MOC_LITERAL(1, 15, 12), // "mailBoxStats"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 15), // "KIMAP::IdleJob*"
QT_MOC_LITERAL(4, 45, 3), // "job"
QT_MOC_LITERAL(5, 49, 7), // "mailBox"
QT_MOC_LITERAL(6, 57, 12), // "messageCount"
QT_MOC_LITERAL(7, 70, 11), // "recentCount"
QT_MOC_LITERAL(8, 82, 26), // "mailBoxMessageFlagsChanged"
QT_MOC_LITERAL(9, 109, 3), // "uid"
QT_MOC_LITERAL(10, 113, 4), // "stop"
QT_MOC_LITERAL(11, 118, 9), // "emitStats"
QT_MOC_LITERAL(12, 128, 12) // "resetTimeout"

    },
    "KIMAP::IdleJob\0mailBoxStats\0\0"
    "KIMAP::IdleJob*\0job\0mailBox\0messageCount\0"
    "recentCount\0mailBoxMessageFlagsChanged\0"
    "uid\0stop\0emitStats\0resetTimeout"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KIMAP__IdleJob[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    4,   39,    2, 0x06 /* Public */,
       8,    2,   48,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    0,   53,    2, 0x0a /* Public */,
      11,    0,   54,    2, 0x08 /* Private */,
      12,    0,   55,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::Int, QMetaType::Int,    4,    5,    6,    7,
    QMetaType::Void, 0x80000000 | 3, QMetaType::LongLong,    4,    9,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KIMAP::IdleJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        IdleJob *_t = static_cast<IdleJob *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->mailBoxStats((*reinterpret_cast< KIMAP::IdleJob*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 1: _t->mailBoxMessageFlagsChanged((*reinterpret_cast< KIMAP::IdleJob*(*)>(_a[1])),(*reinterpret_cast< qint64(*)>(_a[2]))); break;
        case 2: _t->stop(); break;
        case 3: _t->d_func()->emitStats(); break;
        case 4: _t->d_func()->resetTimeout(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KIMAP::IdleJob* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KIMAP::IdleJob* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (IdleJob::*_t)(KIMAP::IdleJob * , const QString & , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IdleJob::mailBoxStats)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (IdleJob::*_t)(KIMAP::IdleJob * , qint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IdleJob::mailBoxMessageFlagsChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KIMAP::IdleJob::staticMetaObject = {
    { &Job::staticMetaObject, qt_meta_stringdata_KIMAP__IdleJob.data,
      qt_meta_data_KIMAP__IdleJob,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KIMAP::IdleJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KIMAP::IdleJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KIMAP__IdleJob.stringdata0))
        return static_cast<void*>(this);
    return Job::qt_metacast(_clname);
}

int KIMAP::IdleJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KIMAP::IdleJob::mailBoxStats(KIMAP::IdleJob * _t1, const QString & _t2, int _t3, int _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KIMAP::IdleJob::mailBoxMessageFlagsChanged(KIMAP::IdleJob * _t1, qint64 _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
