/****************************************************************************
** Meta object code from reading C++ file 'sessionthread_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kimap-17.12.3/src/sessionthread_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sessionthread_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KIMAP__SessionThread_t {
    QByteArrayData data[30];
    char stringdata0[442];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KIMAP__SessionThread_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KIMAP__SessionThread_t qt_meta_stringdata_KIMAP__SessionThread = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KIMAP::SessionThread"
QT_MOC_LITERAL(1, 21, 15), // "socketConnected"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 18), // "socketDisconnected"
QT_MOC_LITERAL(4, 57, 14), // "socketActivity"
QT_MOC_LITERAL(5, 72, 11), // "socketError"
QT_MOC_LITERAL(6, 84, 17), // "KTcpSocket::Error"
QT_MOC_LITERAL(7, 102, 16), // "responseReceived"
QT_MOC_LITERAL(8, 119, 15), // "KIMAP::Response"
QT_MOC_LITERAL(9, 135, 8), // "response"
QT_MOC_LITERAL(10, 144, 27), // "encryptionNegotiationResult"
QT_MOC_LITERAL(11, 172, 22), // "KTcpSocket::SslVersion"
QT_MOC_LITERAL(12, 195, 8), // "sslError"
QT_MOC_LITERAL(13, 204, 15), // "KSslErrorUiData"
QT_MOC_LITERAL(14, 220, 11), // "closeSocket"
QT_MOC_LITERAL(15, 232, 8), // "startSsl"
QT_MOC_LITERAL(16, 241, 7), // "version"
QT_MOC_LITERAL(17, 249, 23), // "sslErrorHandlerResponse"
QT_MOC_LITERAL(18, 273, 6), // "result"
QT_MOC_LITERAL(19, 280, 9), // "reconnect"
QT_MOC_LITERAL(20, 290, 10), // "threadInit"
QT_MOC_LITERAL(21, 301, 10), // "threadQuit"
QT_MOC_LITERAL(22, 312, 11), // "readMessage"
QT_MOC_LITERAL(23, 324, 14), // "writeDataQueue"
QT_MOC_LITERAL(24, 339, 12), // "sslConnected"
QT_MOC_LITERAL(25, 352, 13), // "doCloseSocket"
QT_MOC_LITERAL(26, 366, 15), // "slotSocketError"
QT_MOC_LITERAL(27, 382, 22), // "slotSocketDisconnected"
QT_MOC_LITERAL(28, 405, 10), // "doStartSsl"
QT_MOC_LITERAL(29, 416, 25) // "doSslErrorHandlerResponse"

    },
    "KIMAP::SessionThread\0socketConnected\0"
    "\0socketDisconnected\0socketActivity\0"
    "socketError\0KTcpSocket::Error\0"
    "responseReceived\0KIMAP::Response\0"
    "response\0encryptionNegotiationResult\0"
    "KTcpSocket::SslVersion\0sslError\0"
    "KSslErrorUiData\0closeSocket\0startSsl\0"
    "version\0sslErrorHandlerResponse\0result\0"
    "reconnect\0threadInit\0threadQuit\0"
    "readMessage\0writeDataQueue\0sslConnected\0"
    "doCloseSocket\0slotSocketError\0"
    "slotSocketDisconnected\0doStartSsl\0"
    "doSslErrorHandlerResponse"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KIMAP__SessionThread[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  119,    2, 0x06 /* Public */,
       3,    0,  120,    2, 0x06 /* Public */,
       4,    0,  121,    2, 0x06 /* Public */,
       5,    1,  122,    2, 0x06 /* Public */,
       7,    1,  125,    2, 0x06 /* Public */,
      10,    2,  128,    2, 0x06 /* Public */,
      12,    1,  133,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    0,  136,    2, 0x0a /* Public */,
      15,    1,  137,    2, 0x0a /* Public */,
      17,    1,  140,    2, 0x0a /* Public */,
      19,    0,  143,    2, 0x08 /* Private */,
      20,    0,  144,    2, 0x08 /* Private */,
      21,    0,  145,    2, 0x08 /* Private */,
      22,    0,  146,    2, 0x08 /* Private */,
      23,    0,  147,    2, 0x08 /* Private */,
      24,    0,  148,    2, 0x08 /* Private */,
      25,    0,  149,    2, 0x08 /* Private */,
      26,    1,  150,    2, 0x08 /* Private */,
      27,    0,  153,    2, 0x08 /* Private */,
      28,    1,  154,    2, 0x08 /* Private */,
      29,    1,  157,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::Bool, 0x80000000 | 11,    2,    2,
    QMetaType::Void, 0x80000000 | 13,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,   16,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,    2,
    QMetaType::Void, QMetaType::Bool,   18,

       0        // eod
};

void KIMAP::SessionThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SessionThread *_t = static_cast<SessionThread *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->socketConnected(); break;
        case 1: _t->socketDisconnected(); break;
        case 2: _t->socketActivity(); break;
        case 3: _t->socketError((*reinterpret_cast< KTcpSocket::Error(*)>(_a[1]))); break;
        case 4: _t->responseReceived((*reinterpret_cast< const KIMAP::Response(*)>(_a[1]))); break;
        case 5: _t->encryptionNegotiationResult((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< KTcpSocket::SslVersion(*)>(_a[2]))); break;
        case 6: _t->sslError((*reinterpret_cast< const KSslErrorUiData(*)>(_a[1]))); break;
        case 7: _t->closeSocket(); break;
        case 8: _t->startSsl((*reinterpret_cast< KTcpSocket::SslVersion(*)>(_a[1]))); break;
        case 9: _t->sslErrorHandlerResponse((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->reconnect(); break;
        case 11: _t->threadInit(); break;
        case 12: _t->threadQuit(); break;
        case 13: _t->readMessage(); break;
        case 14: _t->writeDataQueue(); break;
        case 15: _t->sslConnected(); break;
        case 16: _t->doCloseSocket(); break;
        case 17: _t->slotSocketError((*reinterpret_cast< KTcpSocket::Error(*)>(_a[1]))); break;
        case 18: _t->slotSocketDisconnected(); break;
        case 19: _t->doStartSsl((*reinterpret_cast< KTcpSocket::SslVersion(*)>(_a[1]))); break;
        case 20: _t->doSslErrorHandlerResponse((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (SessionThread::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SessionThread::socketConnected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (SessionThread::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SessionThread::socketDisconnected)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (SessionThread::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SessionThread::socketActivity)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (SessionThread::*_t)(KTcpSocket::Error );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SessionThread::socketError)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (SessionThread::*_t)(const KIMAP::Response & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SessionThread::responseReceived)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (SessionThread::*_t)(bool , KTcpSocket::SslVersion );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SessionThread::encryptionNegotiationResult)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (SessionThread::*_t)(const KSslErrorUiData & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SessionThread::sslError)) {
                *result = 6;
                return;
            }
        }
    }
}

const QMetaObject KIMAP::SessionThread::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KIMAP__SessionThread.data,
      qt_meta_data_KIMAP__SessionThread,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KIMAP::SessionThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KIMAP::SessionThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KIMAP__SessionThread.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KIMAP::SessionThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void KIMAP::SessionThread::socketConnected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KIMAP::SessionThread::socketDisconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KIMAP::SessionThread::socketActivity()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KIMAP::SessionThread::socketError(KTcpSocket::Error _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KIMAP::SessionThread::responseReceived(const KIMAP::Response & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KIMAP::SessionThread::encryptionNegotiationResult(bool _t1, KTcpSocket::SslVersion _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KIMAP::SessionThread::sslError(const KSslErrorUiData & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
