/****************************************************************************
** Meta object code from reading C++ file 'session.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kimap-17.12.3/src/session.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'session.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KIMAP__Session_t {
    QByteArrayData data[15];
    char stringdata0[190];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KIMAP__Session_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KIMAP__Session_t qt_meta_stringdata_KIMAP__Session = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KIMAP::Session"
QT_MOC_LITERAL(1, 15, 19), // "jobQueueSizeChanged"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 9), // "queueSize"
QT_MOC_LITERAL(4, 46, 14), // "connectionLost"
QT_MOC_LITERAL(5, 61, 16), // "connectionFailed"
QT_MOC_LITERAL(6, 78, 12), // "stateChanged"
QT_MOC_LITERAL(7, 91, 21), // "KIMAP::Session::State"
QT_MOC_LITERAL(8, 113, 8), // "newState"
QT_MOC_LITERAL(9, 122, 8), // "oldState"
QT_MOC_LITERAL(10, 131, 5), // "State"
QT_MOC_LITERAL(11, 137, 12), // "Disconnected"
QT_MOC_LITERAL(12, 150, 16), // "NotAuthenticated"
QT_MOC_LITERAL(13, 167, 13), // "Authenticated"
QT_MOC_LITERAL(14, 181, 8) // "Selected"

    },
    "KIMAP::Session\0jobQueueSizeChanged\0\0"
    "queueSize\0connectionLost\0connectionFailed\0"
    "stateChanged\0KIMAP::Session::State\0"
    "newState\0oldState\0State\0Disconnected\0"
    "NotAuthenticated\0Authenticated\0Selected"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KIMAP__Session[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       1,   44, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,
       4,    0,   37,    2, 0x06 /* Public */,
       5,    0,   38,    2, 0x06 /* Public */,
       6,    2,   39,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 7,    8,    9,

 // enums: name, flags, count, data
      10, 0x0,    4,   48,

 // enum data: key, value
      11, uint(KIMAP::Session::Disconnected),
      12, uint(KIMAP::Session::NotAuthenticated),
      13, uint(KIMAP::Session::Authenticated),
      14, uint(KIMAP::Session::Selected),

       0        // eod
};

void KIMAP::Session::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Session *_t = static_cast<Session *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->jobQueueSizeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->connectionLost(); break;
        case 2: _t->connectionFailed(); break;
        case 3: _t->stateChanged((*reinterpret_cast< KIMAP::Session::State(*)>(_a[1])),(*reinterpret_cast< KIMAP::Session::State(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Session::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Session::jobQueueSizeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Session::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Session::connectionLost)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Session::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Session::connectionFailed)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Session::*_t)(KIMAP::Session::State , KIMAP::Session::State );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Session::stateChanged)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject KIMAP::Session::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KIMAP__Session.data,
      qt_meta_data_KIMAP__Session,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KIMAP::Session::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KIMAP::Session::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KIMAP__Session.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KIMAP::Session::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KIMAP::Session::jobQueueSizeChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KIMAP::Session::connectionLost()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KIMAP::Session::connectionFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KIMAP::Session::stateChanged(KIMAP::Session::State _t1, KIMAP::Session::State _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
