/****************************************************************************
** Meta object code from reading C++ file 'fetchjob.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kimap-17.12.3/src/fetchjob.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fetchjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KIMAP__FetchJob_t {
    QByteArrayData data[20];
    char stringdata0[323];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KIMAP__FetchJob_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KIMAP__FetchJob_t qt_meta_stringdata_KIMAP__FetchJob = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KIMAP::FetchJob"
QT_MOC_LITERAL(1, 16, 15), // "headersReceived"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 7), // "mailBox"
QT_MOC_LITERAL(4, 41, 19), // "QMap<qint64,qint64>"
QT_MOC_LITERAL(5, 61, 4), // "uids"
QT_MOC_LITERAL(6, 66, 5), // "sizes"
QT_MOC_LITERAL(7, 72, 32), // "QMap<qint64,KIMAP::MessageFlags>"
QT_MOC_LITERAL(8, 105, 5), // "flags"
QT_MOC_LITERAL(9, 111, 30), // "QMap<qint64,KIMAP::MessagePtr>"
QT_MOC_LITERAL(10, 142, 8), // "messages"
QT_MOC_LITERAL(11, 151, 36), // "QMap<qint64,KIMAP::MessageAtt..."
QT_MOC_LITERAL(12, 188, 5), // "attrs"
QT_MOC_LITERAL(13, 194, 16), // "messagesReceived"
QT_MOC_LITERAL(14, 211, 13), // "partsReceived"
QT_MOC_LITERAL(15, 225, 32), // "QMap<qint64,KIMAP::MessageParts>"
QT_MOC_LITERAL(16, 258, 5), // "parts"
QT_MOC_LITERAL(17, 264, 17), // "messagesAvailable"
QT_MOC_LITERAL(18, 282, 27), // "QMap<qint64,KIMAP::Message>"
QT_MOC_LITERAL(19, 310, 12) // "emitPendings"

    },
    "KIMAP::FetchJob\0headersReceived\0\0"
    "mailBox\0QMap<qint64,qint64>\0uids\0sizes\0"
    "QMap<qint64,KIMAP::MessageFlags>\0flags\0"
    "QMap<qint64,KIMAP::MessagePtr>\0messages\0"
    "QMap<qint64,KIMAP::MessageAttribute>\0"
    "attrs\0messagesReceived\0partsReceived\0"
    "QMap<qint64,KIMAP::MessageParts>\0parts\0"
    "messagesAvailable\0QMap<qint64,KIMAP::Message>\0"
    "emitPendings"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KIMAP__FetchJob[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    5,   54,    2, 0x06 /* Public */,
       1,    6,   65,    2, 0x06 /* Public */,
      13,    3,   78,    2, 0x06 /* Public */,
      13,    4,   85,    2, 0x06 /* Public */,
      14,    3,   94,    2, 0x06 /* Public */,
      14,    4,  101,    2, 0x06 /* Public */,
      17,    1,  110,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      19,    0,  113,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, 0x80000000 | 4, 0x80000000 | 4, 0x80000000 | 7, 0x80000000 | 9,    3,    5,    6,    8,   10,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 4, 0x80000000 | 4, 0x80000000 | 11, 0x80000000 | 7, 0x80000000 | 9,    3,    5,    6,   12,    8,   10,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 4, 0x80000000 | 9,    3,    5,   10,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 4, 0x80000000 | 11, 0x80000000 | 9,    3,    5,   12,   10,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 4, 0x80000000 | 15,    3,    5,   16,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 4, 0x80000000 | 11, 0x80000000 | 15,    3,    5,   12,   16,
    QMetaType::Void, 0x80000000 | 18,   10,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void KIMAP::FetchJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FetchJob *_t = static_cast<FetchJob *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->headersReceived((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QMap<qint64,qint64>(*)>(_a[2])),(*reinterpret_cast< const QMap<qint64,qint64>(*)>(_a[3])),(*reinterpret_cast< const QMap<qint64,KIMAP::MessageFlags>(*)>(_a[4])),(*reinterpret_cast< const QMap<qint64,KIMAP::MessagePtr>(*)>(_a[5]))); break;
        case 1: _t->headersReceived((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QMap<qint64,qint64>(*)>(_a[2])),(*reinterpret_cast< const QMap<qint64,qint64>(*)>(_a[3])),(*reinterpret_cast< const QMap<qint64,KIMAP::MessageAttribute>(*)>(_a[4])),(*reinterpret_cast< const QMap<qint64,KIMAP::MessageFlags>(*)>(_a[5])),(*reinterpret_cast< const QMap<qint64,KIMAP::MessagePtr>(*)>(_a[6]))); break;
        case 2: _t->messagesReceived((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QMap<qint64,qint64>(*)>(_a[2])),(*reinterpret_cast< const QMap<qint64,KIMAP::MessagePtr>(*)>(_a[3]))); break;
        case 3: _t->messagesReceived((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QMap<qint64,qint64>(*)>(_a[2])),(*reinterpret_cast< const QMap<qint64,KIMAP::MessageAttribute>(*)>(_a[3])),(*reinterpret_cast< const QMap<qint64,KIMAP::MessagePtr>(*)>(_a[4]))); break;
        case 4: _t->partsReceived((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QMap<qint64,qint64>(*)>(_a[2])),(*reinterpret_cast< const QMap<qint64,KIMAP::MessageParts>(*)>(_a[3]))); break;
        case 5: _t->partsReceived((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QMap<qint64,qint64>(*)>(_a[2])),(*reinterpret_cast< const QMap<qint64,KIMAP::MessageAttribute>(*)>(_a[3])),(*reinterpret_cast< const QMap<qint64,KIMAP::MessageParts>(*)>(_a[4]))); break;
        case 6: _t->messagesAvailable((*reinterpret_cast< const QMap<qint64,KIMAP::Message>(*)>(_a[1]))); break;
        case 7: _t->d_func()->emitPendings(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (FetchJob::*_t)(const QString & , const QMap<qint64,qint64> & , const QMap<qint64,qint64> & , const QMap<qint64,KIMAP::MessageFlags> & , const QMap<qint64,KIMAP::MessagePtr> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FetchJob::headersReceived)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (FetchJob::*_t)(const QString & , const QMap<qint64,qint64> & , const QMap<qint64,qint64> & , const QMap<qint64,KIMAP::MessageAttribute> & , const QMap<qint64,KIMAP::MessageFlags> & , const QMap<qint64,KIMAP::MessagePtr> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FetchJob::headersReceived)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (FetchJob::*_t)(const QString & , const QMap<qint64,qint64> & , const QMap<qint64,KIMAP::MessagePtr> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FetchJob::messagesReceived)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (FetchJob::*_t)(const QString & , const QMap<qint64,qint64> & , const QMap<qint64,KIMAP::MessageAttribute> & , const QMap<qint64,KIMAP::MessagePtr> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FetchJob::messagesReceived)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (FetchJob::*_t)(const QString & , const QMap<qint64,qint64> & , const QMap<qint64,KIMAP::MessageParts> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FetchJob::partsReceived)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (FetchJob::*_t)(const QString & , const QMap<qint64,qint64> & , const QMap<qint64,KIMAP::MessageAttribute> & , const QMap<qint64,KIMAP::MessageParts> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FetchJob::partsReceived)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (FetchJob::*_t)(const QMap<qint64,KIMAP::Message> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FetchJob::messagesAvailable)) {
                *result = 6;
                return;
            }
        }
    }
}

const QMetaObject KIMAP::FetchJob::staticMetaObject = {
    { &Job::staticMetaObject, qt_meta_stringdata_KIMAP__FetchJob.data,
      qt_meta_data_KIMAP__FetchJob,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KIMAP::FetchJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KIMAP::FetchJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KIMAP__FetchJob.stringdata0))
        return static_cast<void*>(this);
    return Job::qt_metacast(_clname);
}

int KIMAP::FetchJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KIMAP::FetchJob::headersReceived(const QString & _t1, const QMap<qint64,qint64> & _t2, const QMap<qint64,qint64> & _t3, const QMap<qint64,KIMAP::MessageFlags> & _t4, const QMap<qint64,KIMAP::MessagePtr> & _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KIMAP::FetchJob::headersReceived(const QString & _t1, const QMap<qint64,qint64> & _t2, const QMap<qint64,qint64> & _t3, const QMap<qint64,KIMAP::MessageAttribute> & _t4, const QMap<qint64,KIMAP::MessageFlags> & _t5, const QMap<qint64,KIMAP::MessagePtr> & _t6)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KIMAP::FetchJob::messagesReceived(const QString & _t1, const QMap<qint64,qint64> & _t2, const QMap<qint64,KIMAP::MessagePtr> & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KIMAP::FetchJob::messagesReceived(const QString & _t1, const QMap<qint64,qint64> & _t2, const QMap<qint64,KIMAP::MessageAttribute> & _t3, const QMap<qint64,KIMAP::MessagePtr> & _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KIMAP::FetchJob::partsReceived(const QString & _t1, const QMap<qint64,qint64> & _t2, const QMap<qint64,KIMAP::MessageParts> & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KIMAP::FetchJob::partsReceived(const QString & _t1, const QMap<qint64,qint64> & _t2, const QMap<qint64,KIMAP::MessageAttribute> & _t3, const QMap<qint64,KIMAP::MessageParts> & _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KIMAP::FetchJob::messagesAvailable(const QMap<qint64,KIMAP::Message> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
