/****************************************************************************
** Meta object code from reading C++ file 'session_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kimap-17.12.3/src/session_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'session_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KIMAP__SessionPrivate_t {
    QByteArrayData data[22];
    char stringdata0[336];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KIMAP__SessionPrivate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KIMAP__SessionPrivate_t qt_meta_stringdata_KIMAP__SessionPrivate = {
    {
QT_MOC_LITERAL(0, 0, 21), // "KIMAP::SessionPrivate"
QT_MOC_LITERAL(1, 22, 27), // "encryptionNegotiationResult"
QT_MOC_LITERAL(2, 50, 0), // ""
QT_MOC_LITERAL(3, 51, 29), // "onEncryptionNegotiationResult"
QT_MOC_LITERAL(4, 81, 11), // "isEncrypted"
QT_MOC_LITERAL(5, 93, 22), // "KTcpSocket::SslVersion"
QT_MOC_LITERAL(6, 116, 10), // "sslVersion"
QT_MOC_LITERAL(7, 127, 15), // "onSocketTimeout"
QT_MOC_LITERAL(8, 143, 11), // "doStartNext"
QT_MOC_LITERAL(9, 155, 7), // "jobDone"
QT_MOC_LITERAL(10, 163, 5), // "KJob*"
QT_MOC_LITERAL(11, 169, 12), // "jobDestroyed"
QT_MOC_LITERAL(12, 182, 16), // "responseReceived"
QT_MOC_LITERAL(13, 199, 15), // "KIMAP::Response"
QT_MOC_LITERAL(14, 215, 15), // "socketConnected"
QT_MOC_LITERAL(15, 231, 18), // "socketDisconnected"
QT_MOC_LITERAL(16, 250, 11), // "socketError"
QT_MOC_LITERAL(17, 262, 17), // "KTcpSocket::Error"
QT_MOC_LITERAL(18, 280, 14), // "socketActivity"
QT_MOC_LITERAL(19, 295, 14), // "handleSslError"
QT_MOC_LITERAL(20, 310, 15), // "KSslErrorUiData"
QT_MOC_LITERAL(21, 326, 9) // "errorData"

    },
    "KIMAP::SessionPrivate\0encryptionNegotiationResult\0"
    "\0onEncryptionNegotiationResult\0"
    "isEncrypted\0KTcpSocket::SslVersion\0"
    "sslVersion\0onSocketTimeout\0doStartNext\0"
    "jobDone\0KJob*\0jobDestroyed\0responseReceived\0"
    "KIMAP::Response\0socketConnected\0"
    "socketDisconnected\0socketError\0"
    "KTcpSocket::Error\0socketActivity\0"
    "handleSslError\0KSslErrorUiData\0errorData"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KIMAP__SessionPrivate[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    2,   77,    2, 0x08 /* Private */,
       7,    0,   82,    2, 0x08 /* Private */,
       8,    0,   83,    2, 0x08 /* Private */,
       9,    1,   84,    2, 0x08 /* Private */,
      11,    1,   87,    2, 0x08 /* Private */,
      12,    1,   90,    2, 0x08 /* Private */,
      14,    0,   93,    2, 0x08 /* Private */,
      15,    0,   94,    2, 0x08 /* Private */,
      16,    1,   95,    2, 0x08 /* Private */,
      18,    0,   98,    2, 0x08 /* Private */,
      19,    1,   99,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool, 0x80000000 | 5,    4,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10,    2,
    QMetaType::Void, QMetaType::QObjectStar,    2,
    QMetaType::Void, 0x80000000 | 13,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 20,   21,

       0        // eod
};

void KIMAP::SessionPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SessionPrivate *_t = static_cast<SessionPrivate *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->encryptionNegotiationResult((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->onEncryptionNegotiationResult((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< KTcpSocket::SslVersion(*)>(_a[2]))); break;
        case 2: _t->onSocketTimeout(); break;
        case 3: _t->doStartNext(); break;
        case 4: _t->jobDone((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 5: _t->jobDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 6: _t->responseReceived((*reinterpret_cast< const KIMAP::Response(*)>(_a[1]))); break;
        case 7: _t->socketConnected(); break;
        case 8: _t->socketDisconnected(); break;
        case 9: _t->socketError((*reinterpret_cast< KTcpSocket::Error(*)>(_a[1]))); break;
        case 10: _t->socketActivity(); break;
        case 11: _t->handleSslError((*reinterpret_cast< const KSslErrorUiData(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (SessionPrivate::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SessionPrivate::encryptionNegotiationResult)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KIMAP::SessionPrivate::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KIMAP__SessionPrivate.data,
      qt_meta_data_KIMAP__SessionPrivate,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KIMAP::SessionPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KIMAP::SessionPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KIMAP__SessionPrivate.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KIMAP::SessionPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void KIMAP::SessionPrivate::encryptionNegotiationResult(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
